---
name: 6. 新硬件贡献
about: 请描述您准备贡献的模型与芯片信息
title: ''
labels: ''
assignees: ''

---

## Checklist:

- [ ] 查找[历史相关issue](https://github.com/PaddlePaddle/PaddleX/issues)寻求解答
- [ ] 翻阅[FAQ](https://paddlepaddle.github.io/PaddleX/main/FAQ.html)
- [ ] 翻阅[PaddleX 文档](https://paddlepaddle.github.io/PaddleX/main/index.html)


# 环境

1. 请提供您使用的PaddlePaddle版本号

2. 请提供您使用的PaddleCustomDevice版本号（如果有）

3. 请提供您使用的PaddleX或者套件的分支信息

4. 请提供您使用的机器环境（操作系统 / 芯片型号 / 硬件驱动版本 / 算子库版本等）

5. 请提供您训练模型的日志

# 复现步骤

请详细描述如何复现该结果（环境准备 / 训练命令 / 精度结果等）
